mvn.independent.sigma.prior: Independence prior for the MVN
Description
A prior for the parameters of the multivariate normal
distribution that assumes Sigma to be a diagonal matrix with elements
modeled by independent inverse Gamma priors. Usage
MvnIndependentSigmaPrior(mvn.prior, sd.prior.list)
Arguments
mvn.prior
An object of class MvnPrior that is the
prior distribution for the multivariate normal mean parameter. sd.prior.list
A list of SdPrior objects modeling
the diagonal elements of the multivariate normal variance matrix. The
off-diagonal elements are assumed to be zero. References
Gelman, Carlin, Stern, Rubin (2003), "Bayesian Data Analysis", Chapman
and Hall.