Learn R Programming

Boom (version 0.4)

normal.inverse.gamma.prior: Normal inverse gamma prior

Description

The NormalInverseGammaPrior is the conjugate prior for the mean and variance of the scalar normal distribution. The model says that $$\frac{1}{\sigma^2} \sim Gamma(df / 2, ss/2) \mu|\sigma \sim N(\mu_0, \sigma^2/\kappa)$$

Usage

NormalInverseGammaPrior(mu.guess, mu.guess.weight = .01, sigma.guess, sigma.guess.weight = 1, ...)

Arguments

mu.guess
The mean of the prior distribution. This is $\mu0$ in the description above.
mu.guess.weight
The number of observations worth of weight assigned to mu.guess. This is $\kappa$ in the description above.
sigma.guess
A prior estimate at the value of sigma. This is $\sqrt{ss/df}$.
sigma.guess.weight
The number of observations worth of weight assigned to sigma.guess. This is $df$.
...
blah

References

Gelman, Carlin, Stern, Rubin (2003), "Bayesian Data Analysis", Chapman and Hall.