Learn R Programming

Boom (version 0.4)

normal.inverse.wishart.prior: Normal inverse Wishart prior

Description

The NormalInverseWishartPrior is the conjugate prior for the mean and variance of the multivariate normal distribution. The model says that $$\Sigma^{-1} \sim Wishart(\nu, S) \mu|\sigma \sim N(\mu_0, \Sigma/\kappa)$$

The $Wishart(S, \nu)$ distribution is parameterized by S, the inverse of the sum of squares matrix, and the scalar degrees of freedom parameter nu.

The distribution is improper if $\nu < dim(S)$.

Usage

NormalInverseWishartPrior(mean.guess, mean.guess.weight = .01, variance.guess, variance.guess.weight = nrow(variance.guess) + 1)

Arguments

mean.guess
The mean of the prior distribution. This is $\mu0$ in the description above.
mean.guess.weight
The number of observations worth of weight assigned to mean.guess. This is $\kappa$ in the description above.
variance.guess
A prior estimate at the value of $\Sigma$. This is $S^{-1}/\nu$ in the notation above.
variance.guess.weight
The number of observations worth of weight assigned to variance.guess. This is $df$.

References

Gelman, Carlin, Stern, Rubin (2003), "Bayesian Data Analysis", Chapman and Hall.