unit.testing: Utilities for Unit Test Output

unit.testingR Documentation

Utilities for Unit Test Output

Description

BOOM's C++ unit tests often write MCMC output to files. The Boom R package includes these tools for inspecting the output.

Usage

PlotUnitTestOutput(fname,
                   dim = NULL,
                   truth = TRUE,
                   thin = 0,
                   burn = 0,
                   style = c("ts", "box"),
                   header = FALSE,
                   ...)

ReadUnitTestOutput(fname, dim=NULL, thin=0, burn=0, ...)

Arguments

fname

The name of a numeric text file containing MCMC output. Each row in the file is one MCMC draw of a parameter.

dim

Either NULL or a vector of dimensions describing the shape of one row in fname.

thin

If greater than zero, read every thin'th row of the file. I.e. if thin = 10 then read every 10th row.

burn

The number of initial rows from the file to remove as MCMC burn-in.

truth

If TRUE then assume the first line of fname contains true values of the simulated parameters. If present these will be highlighted in the plots.

style

Indicates whether time series plots or boxplots should be used to show the output.

header

If TRUE then assume fname contains variable names in the first row.

...

Extra arguments passed to mscan for reading the and 'axis'.

Author(s)

Steven L. Scott

See Also

PlotManyTs, BoxplotTrue, BoxplotMcmcMatrix


Boom documentation built on Sept. 16, 2026, 9:09 a.m.