| unit.testing | R Documentation |
BOOM's C++ unit tests often write MCMC output to files. The Boom R package includes these tools for inspecting the output.
PlotUnitTestOutput(fname,
dim = NULL,
truth = TRUE,
thin = 0,
burn = 0,
style = c("ts", "box"),
header = FALSE,
...)
ReadUnitTestOutput(fname, dim=NULL, thin=0, burn=0, ...)
fname |
The name of a numeric text file containing MCMC output. Each row in the file is one MCMC draw of a parameter. |
dim |
Either |
thin |
If greater than zero, read every |
burn |
The number of initial rows from the file to remove as MCMC burn-in. |
truth |
If |
style |
Indicates whether time series plots or boxplots should be used to show the output. |
header |
If TRUE then assume |
... |
Extra arguments passed to |
Steven L. Scott
PlotManyTs, BoxplotTrue, BoxplotMcmcMatrix
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.